params = [
{
'validationcase':'Abdilla2015endurance',
'wingtype': 'rotary',
'rotorquantity': 4.0,
'endurancemax': 12.0,
'rangemax': 50.0,
'takeoffweight': 1.81,
'batterycapacity': 2200.0,
'batteryvoltage': 11.1,
'batterytype': 'LiPo',
'batterymass': 0.191,
'payload': 0.0,
'rotordiameter': 0.2
},
{
'validationcase':'Chang2016',
'wingtype': 'rotary',
'rotorquantity': 4,
'takeoffweight': 1.3,
'batterytype': 'LiPo',
'batteryvoltage': 11.1,
'batterymass': 0.262,
'props': '10x4.7',
'endurancemax': 15,
'payloadmax': 0.4,
'batterycapacity': 5500,
'payload': 0.095,
'rotordiameter': 0.254
},
{
'validationcase': 'DiFranco2016',
'wingtype': 'rotary',
'rotorquantity': 4,
'takeoffweight': 1.3,
'batterytype': 'LiPo',
'batteryvoltage': 11.1,
'batterymass': 0.262,
'props': '10x4.7',
'endurancemaxhover': 16,
'payloadmax': 0.4,
'batterycapacity': 5500,
'payload': 0.0,
'rotordiameter': 0.254,
'batterycells': 3,
'length': 0.280,
'width': 0.140,
'height': 0.100,
'waterproof': 'no'
},
{
'validationcase':'Dorling2017_3S',
'wingtype': 'rotary',
'rotorquantity': 6,
'takeoffweight': 1.5,
'batterytype': 'LiPo',
'batteryvoltage': 14.8,
'batterymass': 0.5,
'props': '10x4.7',
'endurancemax': 15
},
{
'validationcase':'Dorling2017_4S',
'wingtype': 'rotary',
'rotorquantity': 6,
'takeoffweight': 1.5,
'batterytype': 'LiPo',
'batteryvoltage': 14.8,
'batterymass': 0.5,
'props': '10x4.7'
},
{
'validationcase':'FireFLY6Pro',
'wingtype': 'fixed',
'span': 1.524,
'takeoffweight': 4.5,
'endurancemax': 59,
'max_payload': 0.7,
'cruise_speed': 18,
'VTOL': 'yes',
'batterytype': 'LiHV'
},
{
'validationcase':'FreeflyAlta8',
'wingtype': 'rotary',
'rotorquantity': 8,
'diagonal': 1.325,
'batterycells': 6,
'batteryvoltage': 22.2,
'batterycapacity': 10000,
'batterytype': 'LiPo',
'numbatteries': 2,
'numbatteriesconnection': 'parallel',
'max_takeoffweight': 18.1,
'takeoffweight': 6.2,
'max_payload': 9.1,
'specific_power': 145,
'props': '18x6_Folding',
'motor_max_power_continuous': 350,
'motor_max_power_peak': 950,
'temperaturemin': -20,
'temperaturemax': 45,
'thrust_ratio_at_max_takeoffweight': '1.85:1',
'rotordiameter': 0.4572,
'payload': 0.0
},
{
'validationcase':'Ostler2009',
'wingtype': 'fixed',
'wingarea': 0.321,
'wingspan': 1.06,
'rotorquantity': 1,
'batteryvoltage': 11.1,
'batterycapacity': 1500,
'batterytype': 'LiPo',
'numbatteries': 2,
'numbatteriesconnection': 'parallel',
'takeoffweight': 0.95,
'props': '7x4',
'rotordiameter': 0.1778,
'payload': 0.0,
'motorio': 0.65
},
{
'validationcase':'Stolaroff2018',
'wingtype': 'rotary',
'rotorquantity': 4,
'takeoffweight': 1.3,
'batterytype': 'LiPo',
'batteryvoltage': 11.1,
'batterymass': 0.262,
'props': '10x4.7',
'endurancemaxhover': 16,
'payloadmax': 0.4,
'batterycapacity': 5500,
'payload': 0.0,
'rotordiameter': 0.254,
'batterycells': 3,
'length': 0.280,
'width': 0.140,
'height': 0.100,
'waterproof': 'no'
}
]