params = [
{
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 85.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'missionspeed',
'ylabel': 'alpha',
'title': 'Stolaroff',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.0,
'xend': 15.0,
'xnumber': 10,
'validation': False,
'validationcase': 'Stolaroff2018',
'batterytechnology': 'current'
},
{
'validation': False,
'validationcase': 'Ostler2009',
'drone': True,
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 89.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'missionspeed',
'ylabel': 'power',
'title': 'Ostler2009',
'simulationtype': 'simple',
'xbegin': 0.0,
'xend': 30.0,
'xnumber': 20,
'batterytechnology': 'current'
},
{
'drone': True,
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 89.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'payload',
'ylabel': 'endurance',
'title': 'FreeFLY_Alta8',
'simulationtype': 'simple',
'xbegin': 0.0,
'xend': 10.0,
'xnumber': 100,
'validation': False,
'validationcase': 'FreeFLYAlta8',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'payload',
'ylabel': 'endurance',
'title': 'FreeFLY_Alta8',
'simulationtype': 'simple',
'xbegin': 0.0,
'xend': 1.0,
'xnumber': 20,
'validation': False,
'validationcase': 'FireFLY6Pro',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 90.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'payload',
'ylabel': 'power',
'title': 'First_test',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.5,
'xend': 1.5,
'xnumber': 10,
'validation': False,
'validationcase': 'Dorling2017_3S',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 90.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'payload',
'ylabel': 'power',
'title': 'First_test',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.5,
'xend': 1.5,
'xnumber': 10,
'validation': False,
'validationcase': 'Dorling2017_4S',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'missionspeed',
'ylabel': 'power',
'title': 'DiFranco',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.0,
'xend': 16.0,
'xnumber': 20,
'validation': False,
'validationcase': 'DiFranco2016',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 100.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'missionspeed',
'ylabel': 'power',
'title': 'Stolaroff',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.0,
'xend': 16.0,
'xnumber': 20,
'validation': False,
'validationcase': 'Chang2016',
'batterytechnology': 'current'
},
{
'dronename': 'drone',
'stateofhealth': 90.0,
'startstateofcharge': 100.0,
'altitude': 100.0,
'temperaturesealevel': 15.0,
'rain': False,
'dropsize': 0.0,
'liquidwatercontent': 1.0,
'temperature': 15.0,
'wind': False,
'windspeed': 0.0,
'winddirection': 0.0,
'relativehumidity': 0.0,
'icing': False,
'timestep': 1,
'plot': True,
'xlabel': 'payload',
'ylabel': 'endurance',
'title': 'Abdilla 2015 Endurance vs Payload Validation Test',
'simulationtype': 'simple',
'model': 'abdilla',
'xbegin': 0.4,
'xend': 0.55,
'xnumber': 20,
'validation': False,
'validationcase': 'Abdilla2015endurance',
'batterytechnology': 'current'
}
]